======================================
 Release notes for nitime version 0.7
======================================

Summary of changes
------------------

This is a maintenance release.

Testing in this version no longer depends on nose_.


Contributors to this release
----------------------------

The following people contributed to this release:

* Ariel Rokem
* Eric Larson
* Paul Ivanov
* Takeshi Abe
* Tom Dupré la Tour
* James Franco

.. Note::

   This list was generated using::

   git log --pretty=format:"* %aN" rel/0.5... | sort | uniq

   Please let us know if you should appear on this list and do not, so that we
   can add your name in future release notes.


Detailed stats from the github repository
-----------------------------------------
GitHub stats for the last  310 days.
We closed a total of 19 issues, 9 pull requests and 10 regular
issues; this is the full list (generated with the script
`tools/github_stats.py`):

Pull Requests (9):

* :ghissue:`147`: 'GrangerAnalyzer's causality_xy[i, j] should represent the causality i => j'
* :ghissue:`148`: 'Remove support for Python 3.3'
* :ghissue:`146`: 'BF: Addition (and sub, mul, div, etc.) should work between time-series.'
* :ghissue:`145`: 'BF: Inherit t0 from the source time-series'
* :ghissue:`144`: 'add built files to gitignore'
* :ghissue:`143`: 'Update doc build machinery to Python 3'
* :ghissue:`142`: 'Fixing build dependency on numpy'
* :ghissue:`140`: 'FIX: Fix interpolation of dpss_windows'
* :ghissue:`139`: 'Testing fixes'

Issues (10):

* :ghissue:`147`: "GrangerAnalyzer's causality_xy[i, j] should represent the causality i => j"
* :ghissue:`148`: 'Remove support for Python 3.3'
* :ghissue:`146`: 'BF: Addition (and sub, mul, div, etc.) should work between time-series.'
* :ghissue:`145`: 'BF: Inherit t0 from the source time-series'
* :ghissue:`144`: 'add built files to gitignore'
* :ghissue:`143`: 'Update doc build machinery to Python 3'
* :ghissue:`141`: 'pip install problem with numpy'
* :ghissue:`142`: 'Fixing build dependency on numpy'
* :ghissue:`140`: 'FIX: Fix interpolation of dpss_windows'
* :ghissue:`139`: 'Testing fixes'

.. include:: ../links_names.txt
